'use strict';

// liveReloadで使う変数とか処理を定義
var LIVE_RELOAD_PORT = 35729;
var lrSnippet = require('connect-livereload')({port: LIVE_RELOAD_PORT});
var mountFolder = function (connect, dir) {
    return connect.static(require('path').resolve(dir));
};

module.exports = function(grunt) {

    var pkg, taskName;
    pkg = grunt.file.readJSON('package.json');

    grunt.initConfig({

        //コンパイル
        compass: {
            dist: {
                options: {
                    config: 'config.rb'
                }
            },
            common: {
                options: {
                    config: 'common/config.rb'
                }
            }
        },
        //監視
        watch: {
            options: {
                livereload: LIVE_RELOAD_PORT
            },
            sass: {
                files: [
                    'common/sass/styles.scss',
                    'sass/styles.scss'
                ],
                tasks: ['compass']
            },
            html: {
                files: ['./**/*.html'],
                tasks: ['']
            },
            css: {
                files: ['./**/*.css'],
                tasks: ['']
            },
            js: {
                files: ['./**/*.js'],
                tasks: ['']
            }
        },
        //接続
        connect: {
            options: {
                port: 9000,
                hostname: '0.0.0.0'
            },
            livereload: {
                options: {
                    middleware: function (connect) {
                        return [
                            lrSnippet,
                            mountFolder(connect, './')
                        ];
                    }
                }
            }
        },
        //ブラウザを開く
        open: {
            server: {
                url: 'http://localhost:<%=connect.options.port%>'
            }
        }
    });

    //パッケージの自動読み込み
    for(taskName in pkg.devDependencies) {
        if(taskName.substring(0, 6) == 'grunt-') {
            grunt.loadNpmTasks(taskName);
        }
    }

    //default登録
    grunt.registerTask('default', ['connect', 'open', 'watch']);

    //error処理
    grunt.registerTask('eatwarnings', function() {
        grunt.warn = grunt.fail.warn = function(warning) {
            grunt.log.error(warning);
        };
    });

};